summaryrefslogtreecommitdiffstats
path: root/mdk-stage1/modules.c
diff options
context:
space:
mode:
authorThierry Vignaud <tv@mageia.org>2013-03-23 12:30:25 +0000
committerThierry Vignaud <tv@mageia.org>2013-03-23 12:30:25 +0000
commite9943abec27d5e244f3c3e86ae4905356ab67e85 (patch)
treea869517ec0b994993a7a2ba619d81de2fc72e497 /mdk-stage1/modules.c
parentb8fe5265b23376de2a40a58101188f88c0281626 (diff)
downloaddrakx-e9943abec27d5e244f3c3e86ae4905356ab67e85.tar
drakx-e9943abec27d5e244f3c3e86ae4905356ab67e85.tar.gz
drakx-e9943abec27d5e244f3c3e86ae4905356ab67e85.tar.bz2
drakx-e9943abec27d5e244f3c3e86ae4905356ab67e85.tar.xz
drakx-e9943abec27d5e244f3c3e86ae4905356ab67e85.zip
(my_insmod) rename as (my_modprobe) as it really what it is
Diffstat (limited to 'mdk-stage1/modules.c')
-rw-r--r--mdk-stage1/modules.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/mdk-stage1/modules.c b/mdk-stage1/modules.c
index 0c9aa0c32..f1fd12130 100644
--- a/mdk-stage1/modules.c
+++ b/mdk-stage1/modules.c
@@ -338,9 +338,9 @@ static enum insmod_return insmod_with_deps(const char * mod_name, char * options
#ifndef DISABLE_NETWORK
-enum insmod_return my_insmod(const char * mod_name, enum driver_type type, char * options, int allow_modules_floppy)
+enum insmod_return my_modprobe(const char * mod_name, enum driver_type type, char * options, int allow_modules_floppy)
#else
-enum insmod_return my_insmod(const char * mod_name, enum driver_type type __attribute__ ((unused)), char * options, int allow_modules_floppy)
+enum insmod_return my_modprobe(const char * mod_name, enum driver_type type __attribute__ ((unused)), char * options, int allow_modules_floppy)
#endif
{
int i;
@@ -411,9 +411,9 @@ static enum return_type insmod_with_options(char * mod, enum driver_type type)
strcat(options, mod);
strcat(options, " ");
- strcat(options, answers[0]); // because my_insmod will eventually modify the string
+ strcat(options, answers[0]); // because my_modprobe will eventually modify the string
- if (my_insmod(mod, type, answers[0], 1) != INSMOD_OK) {
+ if (my_modprobe(mod, type, answers[0], 1) != INSMOD_OK) {
stg1_error_message("Insmod failed.");
return RETURN_ERROR;
}